Index: src/hg/hgTracks/container.c
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/hgTracks/container.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -b -B -U 4 -r1.3 -r1.4
--- src/hg/hgTracks/container.c	11 May 2010 01:43:27 -0000	1.3
+++ src/hg/hgTracks/container.c	14 May 2010 21:35:37 -0000	1.4
@@ -10,10 +10,10 @@
 #include "hgTracks.h"
 #include "container.h"
 
 
-static void containerLoad(struct track *track)
-/* containerLoad - call load routine on all children. This one is generic for all containers. */
+void containerLoadItems(struct track *track)
+/* containerLoadItems - call load routine on all children. */
 {
 struct track *subtrack;
 for (subtrack = track->subtracks; subtrack != NULL; subtrack = subtrack->next)
     subtrack->loadItems(subtrack);
@@ -26,9 +26,9 @@
 for (subtrack = track->subtracks; subtrack != NULL; subtrack = subtrack->next)
     subtrack->freeItems(subtrack);
 }
 
-static void containerDraw(struct track *track, int seqStart, int seqEnd,
+void containerDrawItems(struct track *track, int seqStart, int seqEnd,
         struct hvGfx *hvg, int xOff, int yOff, int width, 
         MgFont *font, Color color, enum trackVisibility vis)
 /* Draw items in container. */
 {
@@ -37,9 +37,10 @@
 for (subtrack = track->subtracks; subtrack != NULL; subtrack = subtrack->next)
     {
     if (isSubtrackVisible(subtrack))
 	{
-	subtrack->drawItems(subtrack, seqStart, seqEnd, hvg, xOff, y, width, font, color, vis);
+	subtrack->drawItems(subtrack, seqStart, seqEnd, hvg, xOff, y, width, font, color, 
+		vis);
 	y += subtrack->totalHeight(subtrack, subtrack->limitedVis);
 	}
     }
 }
@@ -80,11 +81,11 @@
     }
 slSort(&track->subtracks, trackPriCmp);
 
 /* Set methods that may be shared by all containers. */
-track->loadItems = containerLoad;
+track->loadItems = containerLoadItems;
 track->freeItems = containerFree;
-track->drawItems = containerDraw;
+track->drawItems = containerDrawItems;
 track->totalHeight = containerTotalHeight;
 
 /* Set methods specific to containers. */
 char *containerType = trackDbSetting(tdb, "container");

